@@ -3,7 +3,7 @@ library(callr)
 
 Sys.unsetenv("R_TESTS")
 
-if (ps::ps_is_supported()) {
+if (ps::ps_is_supported() && Sys.getenv("ON_CRAN") == "true") {
   reporter <- ps::CleanupReporter(testthat::SummaryReporter)$new()
   results <- test_check("callr", reporter = reporter)
   failed <- sum(vapply(results, FUN.VALUE = integer(1), function(r) {
@@ -16,5 +16,9 @@ if (ps::ps_is_supported()) {
 
 } else {
   ## ps does not support this platform
-  test_check("callr", reporter = "summary")
+
+  sysname <- tolower(Sys.info()[["sysname"]])
+  if (sysname != "sunos" || Sys.getenv("NOT_CRAN") == "true") {
+    test_check("callr", reporter = "summary")
+  }
 }
